@@ -1,4 +1,4 @@
-from typing import Any, Dict, TypeVar
+from typing import Any, Dict
 import requests
 
 class HttpClient():
@@ -9,10 +9,10 @@ class HttpClient():
     
     def get(self, type, id = None) -> Dict[str, Any]:
         full_url = f"{self.url}/storage/{type}/{id}"
-        req = requests.get(full_url, headers=self.headers, auth=self.auth)
+        req = requests.get(full_url, headers=self.headers, auth=tuple(self.auth))
         return req.json()
     
     def post(self, type, id = None, payload = None) -> Dict[str, Any]:
         full_url = f"{self.url}/storage/{type}/{id}"
-        req = requests.post(full_url, data=payload, headers=self.headers, auth=self.auth)
+        req = requests.post(full_url, data=payload, headers=self.headers, auth=tuple(self.auth))
         return req.json()
\ No newline at end of file
